@@ -5,7 +5,7 @@ use IO::Socket;
 use Carp;
 use vars qw($VERSION $DEBUG);
 use strict;
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 use constant COMMAND_SLEEP          => "\x00";
 use constant COMMAND_QUIT           => "\x01";
@@ -456,7 +456,8 @@ sub _has_next_packet
 {
 	my $self = shift;
 	#substr($_[0], -1) ne "\xfe";
-	return substr($_[0], -5) ne "\xfe\0\0\x22\x00";
+	#$self->_dump_packet(substr($_[0], -5));
+	return substr($_[0], -5, 1) ne "\xfe";
 }
 
 
@@ -476,6 +477,7 @@ sub _dump_packet {
         $str .= "\n"; 
     }
     print $str;
+    #warn $str;
 }
 
 
@@ -1100,9 +1102,18 @@ L<libmysql>, L<IO::Socket>
 
 Hiroyuki OYAMA E<lt>oyama@module.jpE<gt>
 
+=head1 MAINTAINER
+
+Takuya Tsuchida E<lt>tsucchi at cpan.orgE<gt>
+
+=head1 REPOSITORY
+
+http://github.com/tsucchi/p5-Net-MySQL
+
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (C) 2002 Hiroyuki OYAMA. Japan. All rights reserved.
+Copyright (C) 2002-2011 Hiroyuki OYAMA. Japan. All rights reserved.
+Copyright (C) 2011 Takuya Tsuchida
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
